pub enum SubscriptionState {
Active,
Paused,
Finalized,
}Expand description
Represents the state of a subscription.
This enum defines the possible states of a subscription, which can be either active or paused.
Variants
Active- The subscription is active and randomness is being distributed.Paused- The subscription is paused and randomness distribution is temporarily suspended.Finalized- The subscription is finalized and cannot be resumed.
See Subscription State Lifecycle for more details.
Variants
Active
The subscription is active and randomness is being distributed.
Paused
The subscription is paused and randomness distribution is temporarily suspended.
Finalized
The subscription is finalized and cannot be resumed.